<?php
namespace App\Http\Controllers\Aluno;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

use App\Models\AlunosUnidadesRecursoAvaliacao;
use App\Models\AlunosUnidadesRecursoAvQuestoes;
use App\Models\AlunosUnidadesRecursoAvQuestoesRespostas;
use App\Models\AlunosUnidadesRecurso;
use App\Models\RecursosAvaliacoes;
use App\Models\RecursosBancoQuestoes;
use App\Models\RecursosBancoQuestoesRespostas;
use App\Models\DisciplinasUnidadesRecurso;
use App\Models\AlunosMatriculasDisciplinas;
use App\Models\AlunosMatriculasNota;

class AvaliacaoController extends Controller
{
    private $avaliacao, $questao, $resposta, $recAvaliacao, $bcoQuest, $bcoResp, $discRecurso,
            $matDisciplinas, $notas;

    public function __construct(AlunosUnidadesRecursoAvaliacao $ava,
                                AlunosUnidadesRecursoAvQuestoes $quest,
                                AlunosUnidadesRecursoAvQuestoesRespostas $resp,
                                AlunosUnidadesRecurso $alnRec,
                                RecursosAvaliacoes $recAv,
                                RecursosBancoQuestoes $bcoQuest,
                                RecursosBancoQuestoesRespostas $bcoResp,
                                DisciplinasUnidadesRecurso $discRec,
                                AlunosMatriculasDisciplinas $dsc,
                                AlunosMatriculasNota $nts)
    {
        $this->avaliacao = $ava;
        $this->questao = $quest;
        $this->resposta = $resp;
        $this->alunoRecurso = $alnRec;
        $this->recAvaliacao = $recAv;
        $this->bcoQuestao = $bcoQuest;
        $this->bcoResposta = $bcoResp;
        $this->discRecurso = $discRec;
        $this->matDisciplinas = $dsc;
        $this->notas = $nts;
    }

    /**
     * Atualiza resposta da questão
     *
     * @param integer $idAvaliacao
     * @param Request $request
     * @return void
     */
    public function upResposta(int $idAvaliacao, Request $request)
    {
        $avaliacao = $this->avaliacao->find($idAvaliacao);
        if(!$avaliacao){
            return "Ops! Avaliação não localizada, por favor atualize sua página e tente novamente!";
        }

        $questao = $this->questao->find($request->questao);
        if(!$questao){
            return "Ops! Questão não localizada, por favor atualize sua página e tente novamente!";
        }

        $resposta = $this->resposta->find($request->alternativa);
        if(!$resposta){
            return "Ops! Alternativa de Resposta não localizada, por favor atualize sua página e tente novamente!";
        }

        // zera as outras respostas selecionadas
        $this->resposta->where('alunos_unidades_recursos_av_questoes_resp_id', $request->questao)->update(['opcaoSelecionada' => 0]);

        // atualiza opção de resposta selecionada
        $response = $resposta->update(['opcaoSelecionada' => 1]);

        // verifica se a questão esta correta
        if($resposta->opcaoSelecionada == 1 && $resposta->opcaoCorreta == 1){
            $questao->update(['questaoCorreta' => 1]);
        }else{
            $questao->update(['questaoCorreta' => 0]);
        }

        if($response){
            return 'Alternativa salva com sucesso!';
        }else{
            return 'Ops! Erro ao salvar alternativa, por favor tente novamente!';
        }
    }

    /**
     * Finaliza Avaliação
     *
     * @param Request $request
     * @return void
     */
    public function concluirAvaliacao(Request $request)
    {
        $avaliacao = $this->avaliacao->find($request->avaliacao);
        if(!$avaliacao){
            return "Ops! Avaliação não localizada, por favor atualize sua página e tente novamente!";
        }

        // verifica se há questões não preenchidas
        $validaConclusao = $this->avaliacao->getValidaFinalizacaoAtividade($avaliacao->id);
        if ($validaConclusao->count() > 0) {
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Identificamos que algumas questões não possuem alternativas salvas, por favor revise sua atividade!');
        }

        // verifica se a avaliação vale nota, caso esteja valendo calcula e atualiza nota
        $avNota = $this->avaliacao->getDadosGeraisAvaliacao($avaliacao->id);
        if($avNota->geraNota == 1){
            $questoesCorretas   = $this->questao->getQuestaoAvaliacaoStatus($avaliacao->id, 1)->count();
            $pontosQuestao      = $avNota->valorNota / $avNota->qtdeQuestoes;
            $notaAvaliacao      = $questoesCorretas * $pontosQuestao;
//            echo "Avaliaçao: ".$avaliacao->id."<br />" ;
//            echo "Quanto vale: ".$avNota->valorNota."<br />";
//            echo "Pontos por Questão: ".$pontosQuestao."<br />";
//            echo "Nota da Avaliação: ".$notaAvaliacao;

            // atualiza nota da avaliação
            $response = $avaliacao->update(['dataTermino' => date('Y-m-d H:i:s'), 'valorNotaAv' => $notaAvaliacao, 'statusAvaliacao' => 1]);

            /**
             * Atualização de Nota Final do aluno
             */
            // seleciona nota atual
            $notaAtual = $this->avaliacao->where('alunos_unidades_recursos_id', $avNota->alunos_unidades_recursos_id)->where('notaFinal', 1)->first();
            // lista maior nota de todas
            $maiorNota = $this->avaliacao->getMaiorNota($avNota->alunos_unidades_recursos_id);
            // veririfica se nota permanece ou atualiza
            if($notaAtual && $notaAtual->id != $maiorNota->id){
                // zera nota anterior
                $notaAtual->update(['notaFinal' => 0]);
                // atualiza maior nota
                $maiorNota->update(['notaFinal' => 1]);
            }else{
                $maiorNota->update(['notaFinal' => 1]);
            }


        // caso não esteja valendo nota, apenas atualiza status para concluído
        }else{
            $response = $avaliacao->update(['dataTermino' => date('Y-m-d H:i:s'), 'statusAvaliacao' => 1]);
        }

        /**
         * Atualiza Boletim Acadêmico
         */
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        // seleciona nota atual
        $discRecursos = $this->discRecurso->getRecursoUnidadeDiscCurso($avNota->unidades_recursos_id);
        // pega valor de matricula disciplina no SM para integração do boletim
        $matDisciplina = $this->matDisciplinas->where('alunos_matriculas_id', $idMatricula)
                                            ->where('disciplinas_id', $discRecursos->disciplina_id)
                                            ->first();
        if(!$matDisciplina){
            $this->matDisciplinas->create([
                'alunos_matriculas_id' => $idMatricula,
                'disciplinas_id' => $discRecursos->disciplina_id
            ]);
            $matDisciplina = $this->matDisciplinas->where('alunos_matriculas_id', $idMatricula)
                                        ->where('disciplinas_id', $discRecursos->disciplina_id)
                                        ->first();
        }

        // seleciona notas finais para calculo da média final
        $notas = $this->avaliacao->getNotasDisciplina($idMatricula, $discRecursos->disciplina_id);
        $valorNota = 0;
        if($notas->count() > 0){
            foreach($notas as $nta){
                $valorNota += $nta->valorNotaAv;
            }
        }
        $nota = $this->notas->where('matriculas_disciplinas', $matDisciplina->id)->first();
        // caso não exista registro de nota, sistema cria um novo
        if (!$nota) {
            $this->notas->create([
                'matriculas_disciplinas' => $matDisciplina->id,
                'descAvaliacao' => 'AVO',
                'valorNota' =>$valorNota,
                'tipoRegistro' => 1
            ]);
        } else {
            $nota->update(['valorNota' => $valorNota]);
        }

        if($response){
            return redirect()
                    ->back()
                    ->with('success', 'Avaliação concluída com sucesso!');
        }else{
            return redirect()
                    ->back()
                    ->with('error', 'Erro ao concluir avaliação, atualize sua página e tente novamente!');
        }
    }

    /**
     * Gera nova tentativa de avaliação
     *
     * @param integer $idRecurso
     * @return void
     */
    public function novaAvaliacao(int $idRecurso, Request $request)
    {
        $recursoAluno = $this->alunoRecurso->getAlunoRecurso($request->session()->get('matricula')['idMatricula'], $idRecurso);
        if(!$recursoAluno){
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Recurso não localizado, por favor atualize sua página e tente novamente!');
        }

        /**
         * Verifica dados da atividade para saber se ainda há alternativas disponíveis.
         */
        $dadosAvaliacao = $this->recAvaliacao->getDadosAvaliacao($recursoAluno->unidades_recursos_id);
        /**
         * Verifica se numero de tentativas foram atingidas
         */
        $avTentativas = $this->avaliacao->where('alunos_unidades_recursos_id', $recursoAluno->id)->count();
        if($dadosAvaliacao->qtdeTentativas <= $avTentativas){
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Parece que você já chegou ao limite de tentantivas desta avaliação!');
        }

        /**
         * Abre nova atividade na tabela de alunos unidades recursos avaliacao
         */
        $response = $this->avaliacao->create([
            'alunos_unidades_recursos_id' =>$recursoAluno->id,
            'dataInicio' => date('Y-m-d H:i:s'),
            'statusAvaliacao' => 0
        ]);

        if($response){
            return redirect()
                    ->route('disciplina.recurso', [$idRecurso])
                    ->with('success', 'Avaliação gerada com sucesso!');
        }else{
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Erro ao gerar avaliação, por favor atualize sua página e tente novamente!');
        }
    }

}
