<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Aluno;
use App\Models\Alunos_fatura;
use App\Models\Alunos_matricula;
use App\Models\Alunos_respFinanceiro;
use App\Models\Boletos_config;
use App\Models\BoletosPagos;
use App\Models\Empresa;
use App\Models\Curso;
use App\Models\Turma;
use App\Models\TurmasBolsasDescontos;

use App\User;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class AlunoController extends Controller
{

    private $aluno, $pagtos, $faturas, $matricula, $empresa, $respFinanceiro, $bolsa;
    private $turma;
    private $curso;

    public function __construct(
        Aluno $aln,
        BoletosPagos $pg,
        Alunos_fatura $fat,
        Empresa $emp,
        Alunos_matricula $mat,
        Alunos_respFinanceiro $resp,
        TurmasBolsasDescontos $bls,
        Turma $turma,
        Curso $curso
    ) {
        $this->aluno            = $aln;
        $this->pagtos           = $pg;
        $this->faturas          = $fat;
        $this->empresa          = $emp;
        $this->respFinanceiro   = $resp;
        $this->bolsa            = $bls;
        $this->matricula        = $mat;
        $this->turma            = $turma;
        $this->curso            = $curso;
    }

    /*******************************************************************************
     * BOLETOS
     ******************************************************************************/
    public function boletos(Alunos_fatura $fat)
    {
        // verifica se sessão ainda esta ativa
        if (!isset(auth()->user()->statusAluno)) {
            $response['message'] = 'Sessão encerrada por inatividade.';
            Auth::logout();
            return redirect()
                ->route('form.loginCPF')
                ->with('error', $response['message']);
        }
        // verifica se a matricula foi cancelada
        if (auth()->user()->statusAluno == 0) {
            $response['message'] = 'Sua matrícula foi cancelada, você não pode acessar o sistema.';
            Auth::logout();
            return redirect()
                ->route('form.loginCPF')
                ->with('error', $response['message']);
        }
        $lista = $fat->getFaturasAluno(auth()->user()->id);
        return view('aluno.boletos', compact('lista'));
    }

    public function boletosMoodle(Request $request)
    {

        // verifica se sessão matricula já foi iniciada
        if (!isset($request->session()->get('matricula')['idMatricula'])) {
            return redirect()
                ->route('home.moodle')
                ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        //$idAluno = $request->session()->get('aluno')['idAluno'];
        $idAluno = auth()->user()->id;
        $idMatricula = $request->session()->get('matricula')['idMatricula'];

        //Modulo de teste
        $matricula = $this->matricula->find($idMatricula);
        // dd(Illuminate\Support\Facades\Hash::make('s170111a'));

        $dataVcto = date('Y-m-d', strtotime('+46 days', strtotime(date('Y-m-d'))));
        $ln = $this->faturas->getFaturasAlunoMatricula($idAluno, $idMatricula, $dataVcto);
        $lista = [];
        if (count($ln) > 0) {
            foreach ($ln as $ls) {

                $totalDesconto = $ls->valorDesconto + $ls->valorDesconto2;

                $totalFatura = $ls->valorFatura - $totalDesconto;

                if ($totalFatura < 0) {
                    $totalFatura = 0.00;
                }

                // verifica se a fatura esta paga
                $pagto = $this->pagtos->getFaturaID($ls->id)->first();
                if (is_array($pagto) && count($pagto) > 0) {
                    $valorRecebido = number_format($pagto->valorRecebido, 2, ',', '.');
                    $dataCredito = ($pagto->dataCredito != "") ? date('d/m/Y', strtotime($pagto->dataCredito)) : '';
                } else {
                    $valorRecebido = '';
                    $dataCredito = '';
                }

                if (!empty($ls->qtdeParcela) && $ls->qtdeParcela > 0 && $ls->parcelaCorrente > 0 && !empty($ls->parcelaCorrente)) {
                    $parcelas = $ls->parcelaCorrente . '/' . $ls->qtdeParcela;
                } else {
                    $parcelas = '';
                }

                $lnFat = [
                    'idFatura' => $ls->id,
                    'dataVcto' => implode("/", array_reverse(explode("-", $ls->dataVcto))),
                    'codFatura' => $ls->codFatura,
                    'valorFatura' => number_format($ls->valorFatura, 2, ',', '.'),
                    'valorDesconto' => number_format($ls->valorDesconto, 2, ',', '.'),
                    'valorDesconto2' => number_format($ls->valorDesconto2, 2, ',', '.'),
                    'totalDesconto' => number_format($totalDesconto, 2, ',', '.'),
                    'totalFatura' => number_format($totalFatura, 2, ',', '.'),
                    'valorRecebido' => $valorRecebido,
                    'dataCredito' => $dataCredito,
                    'parcelas' => $parcelas,
                    'statusFatura' => $ls->statusFatura
                ];
                array_push($lista, $lnFat);
            }
        }
        // configuração de inadimplencia
        $mensagemInadimplente = null;
        if ($request->session()->get('matricula')['inadimplente'] == 1) {
            $mensagemInadimplente = 'Prezado aluno, <a href="' . route('boleto.negociacao') . '" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }

        return view('financeiro.boletosMoodle', compact('lista', 'mensagemInadimplente'));
    }

    // emissão de boleto
    public function getBoleto(Request $request, Aluno $aln, Alunos_fatura $fat, Alunos_matricula $mat, Empresa $emp, Turma $trm, Boletos_config $config)
    {
        $fatura = $fat->find($request->id);
        $matricula = $mat->find($fatura->alunos_matriculas_id);
        $empresa = $emp->find($matricula->empresas_id);
        $aluno = $aln->find($matricula->alunos_id);
        $turma = $trm->find($matricula->turmas_id);
        $boleto = $config->getConfigBoletoEmpresa($matricula->empresas_id);

        if (count($boleto) == 0) {
            return redirect()->back()->with('error', 'Não há configurações de Boletos cadastradas!');
        }

        $dataVcto = new Carbon(date($fatura->dataVcto, strtotime('+0 days')));

        // verifica data de vcto com data atual de emissão para desconto pontualidade
        if ($fatura->dataVcto >= date('Y-m-d')) {
            $valorFatura = $fatura->valorFatura - $fatura->valorDesconto2;
            $descDesconto = 'Conceder desconto de R$: ' . number_format($fatura->valorDesconto, 2, ',', '.') . ' referente: ' . $empresa->razaoSocial . ' - Aluno - até o vencimento';
        } else {
            $valorFatura = $fatura->valorFatura - $fatura->valorDesconto2;
            $descDesconto = '';
        }

        // dados do beneficiário
        $beneficiario = new \Eduardokum\LaravelBoleto\Pessoa([
            'documento' => $empresa->cnpjEmpresa,
            'nome'      => $empresa->razaoSocial,
            'cep'       => $empresa->cepEmpresa,
            'endereco'  => $empresa->enderecoEmpresa,
            'bairro'    => $empresa->bairroEmpresa,
            'uf'        => $empresa->ufEmpresa,
            'cidade'    => $empresa->cidadeEmpresa,
        ]);

        // dados do pagador
        $pagador = new \Eduardokum\LaravelBoleto\Pessoa([
            'documento' => $aluno->cpfAluno,
            'nome'      => $aluno->nomeAluno,
            'cep'       => $aluno->cepAluno,
            'endereco'  => $aluno->enderecoAluno,
            'bairro'    => $aluno->bairroAluno,
            'uf'        => $aluno->ufAluno,
            'cidade'    => $aluno->cidadeAluno,
        ]);

        // dados do boleto
        /*
        $santander = new \Eduardokum\LaravelBoleto\Boleto\Banco\Santander;
        $santander->setLogo('./imagens/line.png')
                  ->setDataVencimento('2018-10-07 18:14:14')
                  ->setValor($fatura->valorFatura)
                  ->setNumero($fatura->parcelaCorrente)
                  ->setNumeroDocumento($fatura->codFatura)
                  ->setPagador($pagador)
                  ->setBeneficiario($beneficiario)
                  ->setCarteira($boleto[0]->carteiraBanco)
                  ->setCodigoCliente($boleto[0]->codCliente)
                  ->setDescricaoDemonstrativo([$turma->siglaTurma.' '.$turma->nomeCurso.' '.$turma->nomeTurma])
                  ->setInstrucoes([$boleto[0]->instrucoesGerais]);

        $santander->addDescricaoDemonstrativo('Fatura num.: '.$fatura->codFatura.' - Referente a Matrícula num.: '.$matricula->codMatricula);
        //$santander->addInstrucao('Instrução 2');
        */
        $santander = new \Eduardokum\LaravelBoleto\Boleto\Banco\Santander([
            'logo' => './imagens/line.png',
            'agencia' => $boleto[0]->agenciaBanco,
            'conta' => $boleto[0]->contaBanco,
            'dataVencimento' => $dataVcto,
            'dataDesconto' => $dataVcto,
            'valor' => $valorFatura,
            'desconto' => $fatura->valorDesconto2,
            'numero' => $boleto[0]->contaBanco,
            'numeroDocumento' => $fatura->codFatura,
            'numeroControle' => $fatura->codFatura,
            'pagador' => $pagador,
            'especieDoc' => 'DS',
            'beneficiario' => $beneficiario,
            'carteira' => $boleto[0]->carteiraBanco,
            'codigoCliente' => $boleto[0]->codCliente,
            'descricaoDemonstrativo' => [$turma->siglaTurma . ' ' . $turma->nomeCurso . ' ' . $turma->nomeTurma, $boleto[0]->instrucoesGerais, $descDesconto],
            'instrucoes' => [$turma->siglaTurma . ' ' . $turma->nomeCurso . ' ' . $turma->nomeTurma, $boleto[0]->instrucoesGerais, $descDesconto],
        ]);
        $santander->getJurosApos(10);
        // renderiza boleto
        return $santander->renderHTML($print = true, $instrucoes = true);
    }

    // lista boletos para o moodle
    public function getBoletoMoodle(Request $request, Alunos_fatura $fat)
    {
        $idAluno = base64_decode(base64_decode(base64_decode($request->id)));

        $lista = $fat->getFaturasAluno($idAluno);
        return view('aluno.boletosMoodle', compact('lista'));
    }



    /*******************************************************************************
     * SENHA
     ******************************************************************************/
    /**
     * Form de edição de dados do aluno
     *
     * @param Request $request
     * @return void
     */
    public function atualizaDados(Request $request)
    {

        // verifica se sessão matricula já foi iniciada
        if (!isset($request->session()->get('matricula')['idMatricula'])) {
            return redirect()
                ->route('home.moodle')
                ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        //$idAluno = $request->session()->get('aluno')['idAluno'];
        $idAluno = auth()->user()->id;

        $aluno = $this->aluno->find($idAluno);

        // configuração de inadimplencia
        $mensagemInadimplente = null;
        if ($request->session()->get('matricula')['inadimplente'] == 1) {
            $mensagemInadimplente = 'Prezado aluno, <a href="' . route('boleto.negociacao') . '" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }

        return view('aluno.senha', compact('aluno', 'mensagemInadimplente'));
    }

    /**
     * Atualização de senha
     *
     * @param Request $request
     * @return void
     */
    public function upDados(Request $request)
    {

        $dados = [
            'foneFixo'          => $request->fone,
            'foneCelular'       => $request->celular,
            'emailAluno'        => $request->email,
            'nomeAluno'         => $request->nome,
            'profissaoAluno'    => $request->profissa,
            'rgAluno'           => $request->rg,
            'dataExpedicaoRG'   => implode("-", array_reverse(explode("/", $request->dataExped))),
            'sexoAluno'         => $request->sexo,
            'estadoCivil'       => $request->estadoCiv,
            'nomeMae'           => $request->nomeMae,
            'nomePai'           => $request->nomePai,
            'cepAluno'          => $request->cep,
            'enderecoAluno'     => $request->endereco,
            'bairroAluno'       => $request->bairro,
            'cidadeAluno'       => $request->cidade,
            'ufAluno'           => $request->estado,
            // 'password'      => Hash::make($request->password)
        ];

        if (isset($request->password)) $dados['password'] = Hash::make($request->password);

        $response = $this->aluno->where('id', auth()->user()->id)->update($dados);

        if ($response) {
            return redirect()
                ->route('aluno.dados')
                ->with('success', 'Dados atualizado com sucesso!');
        } else {
            return redirect()
                ->back()
                ->with('error', 'Ops! Houve uma falha ao atualizar suas informações, por favor tente novamente!');
        }
    }

    // update senhas
    public function updateSenhas(User $usr)
    {
        $lista = $usr->all();
        echo '<ol>';
        foreach ($lista as $ln) {
            $cpfAluno = str_replace("-", "", $ln->cpfAluno);
            $cpfAluno = str_replace(".", "", $cpfAluno);
            echo '<li>' . $cpfAluno . "</li>";
            $dados = [
                'password' => bcrypt($cpfAluno)
            ];
            //dd($request);
            $usr->upAluno($ln->id, $dados);
            $cpfAluno = "";
        }
        echo '</ol>';
    }

    /*******************************************************************************
     * CONTRATO
     ******************************************************************************/
    /**
     * Gera contrato Educacional do Aluno Presencial
     *
     * @param Request $request
     * @param Empresa $emp
     * @param Aluno $aln
     * @param Alunos_matricula $mat
     * @param Alunos_fatura $fat
     * @param Alunos_respFinanceiro $fin
     * @param Curso $crs
     * @param Turma $trm
     * @return void
     */
    public function contrato(Request $request, Empresa $emp, Aluno $aln, Alunos_matricula $mat, Alunos_fatura $fat, Alunos_respFinanceiro $fin, Curso $crs, Turma $trm)
    {

        // verifica se sessão matricula já foi iniciada
        if (!isset($request->session()->get('matricula')['idMatricula'])) {
            return redirect()
                ->route('home.moodle')
                ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        $idMatricula = $request->session()->get('matricula')['idMatricula'];

        $matricula = $mat->find($idMatricula);
        $aluno = $aln->find($matricula->alunos_id);
        $turma = $trm->find($matricula->turmas_id);
        $curso = $crs->find($turma->cursos_id);


        // verifica se o curso é promo
        if ($curso->cursoPromo == 1) {
            $empresa = $emp->find(9);
        } else {
            $empresa = $emp->find($matricula->empresas_id);
        }

        $empresa2 = $emp->find(7);

        $respFin = $fin->getRespFinAluno($aluno->id);
        $faturas = $fat->getFaturasContratoAluno($idMatricula);


        if ($matricula->created_at) {
            $meses = ['01' => 'Janeiro', '02' => 'Fevereiro', '03' => 'Março', '04' => 'Abril', '05' => 'Maio', '06' => 'Junho', '07' => 'Julho', '08' => 'Agosto', '09' => 'Setembro', '10' => 'Outubro', '11' => 'Novembro', '12' => 'Dezembro'];
            $dtMat = explode('-', $matricula->created_at);

            $dataMatricula = substr($dtMat[2], 0, 2) . ' de ' . $meses[$dtMat[1]] . ' de ' . $dtMat[0];
        } else {
            $dataMatricula = '';
        }


        return view('aluno.contrato', compact('matricula', 'curso', 'turma', 'respFin', 'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula'));
    }

    /**
     * Gera contrato Educacional do Aluno EAD
     *
     * @param Request $request
     * @param Empresa $emp
     * @param Aluno $aln
     * @param Alunos_matricula $mat
     * @param Alunos_fatura $fat
     * @param Alunos_respFinanceiro $fin
     * @param Curso $crs
     * @param Turma $trm
     * @return void
     */
    public function contratoEAD(Request $request, Aluno $aln, Alunos_fatura $fat, Curso $crs, Turma $trm)
    {

        // verifica se sessão matricula já foi iniciada
        if (!isset($request->session()->get('matricula')['idMatricula'])) {
            return redirect()
                ->route('home.moodle')
                ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }

        $idMatricula = $request->session()->get('matricula')['idMatricula'];

        $matricula = $this->matricula->find($idMatricula);
        $aluno = $this->aluno->find($matricula->alunos_id);
        $turma = $trm->find($matricula->turmas_id);
        $curso = $crs->find($turma->cursos_id);
        $bolsa = $this->bolsa->find($matricula->bolsas_id);
        $datahj = '2022-02-15 00:00:00';

        // verifica se o curso é promo
        if ($curso->cursoPromo == 1) {
            $empresa = $this->empresa->find(9);
        } else {
            $empresa = $this->empresa->find($matricula->empresas_id);
        }

        $empresa2 = $this->empresa->find(7);

        $respFinanceiro = $this->respFinanceiro->getRespFinAluno($aluno->id);
        $faturas = $fat->getFaturasContratoAluno($idMatricula);
        if ($matricula->created_at) {
            $meses = ['01' => 'Janeiro', '02' => 'Fevereiro', '03' => 'Março', '04' => 'Abril', '05' => 'Maio', '06' => 'Junho', '07' => 'Julho', '08' => 'Agosto', '09' => 'Setembro', '10' => 'Outubro', '11' => 'Novembro', '12' => 'Dezembro'];
            $dtMat = explode('-', $matricula->created_at);

            $diasSemana = ['Domingo', 'Segunda', 'Terça', 'Quarta', 'Quinta', 'Sexta', 'Sábado'];
            $numDiaSemana = date('w', strtotime($matricula->created_at));

            $diaSemana = $diasSemana[$numDiaSemana];

            $dataMatricula = substr($dtMat[2], 0, 2) . ' de ' . $meses[$dtMat[1]] . ' de ' . $dtMat[0];
        } else {
            $dataMatricula = '';
        }


        // identifica aluno no pronapos 350
        $obs = explode('+', $matricula->observacoes);

        if ($matricula->created_at >= $datahj && $matricula->empresas_id == 16 || $matricula->created_at >= $datahj && $matricula->empresas_id == 10 || $matricula->created_at >= $datahj && $matricula->empresas_id == 12){
            return view ('documentos.contrato_SL', compact('matricula', 'curso', 'turma',  'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'respFinanceiro'));
        }
        if ($obs[0] == 'matsis') {
            if ($matricula->empresas_id == 7 && $matricula->modalidade == 2) {
                return view('documentos.contratoEAD', compact('matricula', 'curso', 'turma',  'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'respFinanceiro'));
            } else if ($matricula->empresas_id == 6 && $matricula->modalidade == 2 || $matricula->empresas_id == 17 && $matricula->modalidade == 2) {
                return view('documentos.contratoeadcarreira', compact('matricula', 'curso', 'turma',  'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'respFinanceiro'));
            } else if ($matricula->modalidade == 3) {
                return view('documentos.contratoSisSemi', compact('matricula', 'curso', 'turma',  'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'respFinanceiro'));
            }
        } else if (in_array($matricula->bolsas_id, [276, 281])) {
            if ($matricula->empresas_id == 17 && $matricula->modalidade == 2) {
                return view('documentos.contratoeadcarreira', compact('matricula', 'curso', 'turma',  'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'respFinanceiro'));
            } else {
                return view('documentos.contratoEAD_prona350', compact('matricula', 'bolsa', 'curso', 'turma', 'respFinanceiro', 'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'diaSemana'));
            }
        } else if ($matricula->modalidade == 3) {

            return view('documentos.contratoSemi', compact('matricula', 'bolsa', 'curso', 'turma', 'respFinanceiro', 'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'diaSemana'));
        } else if ($matricula->empresas_id == 6 && $matricula->modalidade == 2) {
            return view('documentos.contratoeadcarreira', compact('matricula', 'curso', 'turma',  'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'respFinanceiro'));
        } else if ($matricula->empresas_id == 17 && $matricula->modalidade == 2) {
            return view('documentos.contratoeadcarreira', compact('matricula', 'curso', 'turma',  'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'respFinanceiro'));
        } else {
            return view('documentos.contratoEAD', compact('matricula', 'bolsa', 'curso', 'turma', 'respFinanceiro', 'faturas', 'aluno', 'empresa', 'empresa2', 'dataMatricula', 'diaSemana'));
        }
    }

    /**
     * atualiza dados de aluno reativado
     */

    public function atualizaDadosAlunoReativado(Request $request)
    {
        // dd($request->emailAluno, $request->password, $request->nomeSocial);
        $matricula  = json_decode($request->matricula);

        if (! $request->password || !$request->nomeSocial || !$request->emailAluno) {
            return json_encode([
                "success"   => false,
                "msg"       => "O preenchimento de todos os dados é obrigatório",
                "response"  => null
            ]);
        }

        $matricula = $this->matricula->where('id', $matricula->id)->first();
        if (!$matricula) {
            return json_encode([
                "success"   => false,
                "msg"       => "Matricula não encontrada",
                "response"  => null
            ]);
        }

        $user = User::find($matricula->alunos_id);
        $user->nomeSocial   = $request->nomeSocial;
        $user->email        = $request->emailAluno;
        $user->emailAluno   = $request->emailAluno;
        $user->password     =  Hash::make($request->password);
        $response           = $user->update();

        if (!$response) {
            return json_encode([
                "success"   => false,
                "msg"       => "Falha na atualização do aluno",
                "response"  => null
            ]);
        }

        $matricula->motivoCancelamento = str_replace('#canceladoAutomaticamente', '', $matricula->motivoCancelamento);
        $matricula->statusMatricula = 1;
        $response = $matricula->update();

        if (!$response) {
            return json_encode([
                "success"   => false,
                "msg"       => "Falha na atualização da matricula",
                "response"  => null
            ]);
        }

        $login = Auth::attempt(['emailAluno' => $request->emailAluno, 'password' => $request->password]);
        if (!$login) {
            return json_encode([
                "success"   => false,
                "msg"       => "Falha no login",
                 "response" => null
            ]);
        }

        $aluno = $this->aluno->find($matricula->alunos_id);
        $turma = $this->turma->find($matricula->turmas_id);
        $curso = $this->curso->find($turma->cursos_id);

        if (in_array($matricula->empresas_id, [6,13])) {
            $emailPagseguro = env('PAGSEGURO_IC_EMAIL');
            $tokenPagseguro = env('PAGSEGURO_IC_TOKEN');
        } else if (in_array($matricula->empresas_id, [9,10,12,14,15,16,17,18])) {
            $emailPagseguro = env('PAGSEGURO_INX_EMAIL');
            $tokenPagseguro = env('PAGSEGURO_INX_TOKEN');
        } else {
            $emailPagseguro = env('PAGSEGURO_EMAIL');
            $tokenPagseguro = env('PAGSEGURO_TOKEN');
        }

        $request->session()->put('matricula', [
            'idMatricula'           => $matricula->id,
            'codMatricula'          => $matricula->codMatricula,
            'nomeAluno'             => $aluno->nomeAluno,
            'idCurso'               => $curso->id,
            'siglaCurso'            => $curso->siglaCurso,
            'nomeCurso'             => $curso->nomeCurso,
            'idTurma'               => $turma->id,
            'nomeTurma'             => $turma->nomeTurma,
            'modalidade'            => $matricula->modalidade,
            'inadimplente'          => $matricula->inadimplente,
            'linkava'               => $matricula->linkAva(),
            'tipoCurso'             => $curso->tipoCurso,
            'bolsa'                 => $matricula->bolsas_id,
            'bloqueioSAV'           => false,
            'idEmpresa'             => $matricula->empresas_id,
            'pagseguro_email'       => $emailPagseguro,
            'pagseguro_token'       => $tokenPagseguro,
            'nickempresa'           => Alunos_matricula::find($matricula->id)->nickEmpresa()

        ]);

        $request->session()->put('aluno', [
            'idAluno'   => $aluno->id,
            'nomeAluno' => $aluno->nomeAluno,
            'cpfAluno'  => $aluno->cpfAluno
        ]);

        return json_encode([
            "success"   => true,
            "msg"       => "Atualização efetuada com sucesso!",
            "response"  => [
                "route" => route("ambientacao.inicio")
            ]
        ]);
    }
}
