<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\PesquisasAluno;
use App\Models\PesquisasPergunta;
use App\Models\PesquisasResposta;
use App\Models\AlunosMatriculasDisciplinas;
use App\Models\TurmasDisciplinasAula;
use App\Models\Usuario;
use App\Models\AulasProfessores;
use App\Models\AulasProfessoresTurmas;
use App\Models\Empresa;
use App\Models\Alunos_matricula;
use App\Models\Alunos_fatura;

class FeedbackController extends Controller
{
    private $pesqAluno, $pesqPergunta, $pesqResposta, $alnDisciplinas, $aulasTurmas, $usuario, 
            $aulaProfessor, $aulaProfTurma, $empresa, $matricula;

    public function __construct(PesquisasAluno $psqAln,
                                PesquisasResposta $psqRsp,
                                PesquisasPergunta $psqPrg,
                                AlunosMatriculasDisciplinas $alnDsc,
                                TurmasDisciplinasAula $trmAula,
                                Usuario $user,
                                AulasProfessores $prof,
                                AulasProfessoresTurmas $prfTrm,
                                Empresa $emp,
                                Alunos_matricula $mat,
                                Alunos_fatura $fat)
    {
        $this->pesqAluno = $psqAln;
        $this->pesqPergunta = $psqPrg;
        $this->pesqResposta = $psqRsp;
        $this->alnDisciplinas = $alnDsc;
        $this->aulasTurmas = $trmAula;
        $this->usuario = $user;
        $this->aulaProfessor = $prof;
        $this->aulaProfTurma = $prfTrm;
        $this->empresa = $emp;
        $this->matricula = $mat;
        $this->faturas = $fat;
    }


    /**
     * Lista aulas disponíveis para resposta de feedback
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {
        // caso a sessão não exista redireciona para tela de login
        if(!isset($request->session()->get('aluno')['cpfAluno'])){
            return redirect()->route('login');
        }

        // caso a matricula não tenha sido selecionada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            $matriculas = $this->matricula->getMatriculaAluno($request->session()->get('aluno')['cpfAluno']);
            return view('home.indexMoodle', compact('matriculas')); 
        }

        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        $matricula = $this->matricula->find($idMatricula);

        // lista aulas e feedbacks realizados ou a realizar
        $listaDisciplinas = $this->alnDisciplinas->getDisciplinasMatriculaFeedback($matricula->id, $matricula->turmas_id, $matricula->codAno);
        $listaModulos = [];

        $i = 1;
        foreach($listaDisciplinas as $ls){

            // lista somente aulas com professores registrados
            if($ls->idDocente && $ls->idDisciplina){

                // verifica datas de aulas
                $aulas = $this->aulasTurmas->where('turmas_id', $ls->turmas_id)
                                        ->where('disciplinas_id', $ls->idDisciplina)
                                        ->where('users_id', $ls->idDocente)     
                                        ->where('anoExercicio', $matricula->codAno)                                  
                                        ->orderBy('dataAula', 'asc')
                                        ->get();

                $x = 1;
                foreach($aulas as $aul){
                    // pega primeira data de aula
                    if($x == 1){
                        $dataInicio = $aul->dataAula;                    
                    }
                    $x++;
                }
                $dataFim = $aul->dataAula;
                $i++;

                /**
                 * Verifica se registro de Aulas Professores já existe
                 */      
                $lnAula = [
                    'disciplina' => $ls->idDisciplina,
                    'docente' => $ls->idDocente,
                    'turma' => $ls->turmas_id,
                    'dataInicio' => $dataInicio,
                    'dataFim' => $dataFim
                ];
                $aulaProfessor = $this->aulaProfessor->getConsultaAulaProfessor($lnAula);

                // caso não exista add registro
                if(!$aulaProfessor){                    

                    // registra aula professor
                    $respAula = $this->aulaProfessor->create([
                        'disciplinas_id' => $ls->idDisciplina,
                        'users_id' => $ls->idDocente,
                        'aulas_salas_id' => 13,
                        'dataInicio' => $dataInicio,
                        'dataFim' => $dataFim                        
                    ]);

                    // registra turma aula professor
                    $this->aulaProfTurma->create([
                        'aulas_professores_id' => $respAula->id,
                        'turmas_id' => $ls->turmas_id
                    ]);

                    $aulaProfessor = $this->aulaProfessor->getConsultaAulaProfessor($lnAula);
                }

                /**
                 * Pesquisa Feedback se foi criado ou não
                 * Caso não tenha sido, cria
                 */
                $pesquisa = $this->pesqAluno->getPesquisaModuloAluno($aulaProfessor->id, $idMatricula);
                if(!$pesquisa){
                    $respPesquisa = $this->pesqAluno->create([
                        'aulas_professores_id' => $aulaProfessor->id,
                        'alunos_matriculas_id' => $idMatricula,
                    ]);

                    $pesquisa = $this->pesqAluno->getPesquisaModuloAluno($aulaProfessor->id, $idMatricula);
                }
            
                // pega nome do professor(a)
                $docente = $this->usuario->find($ls->idDocente);

                if($dataFim <= '2019-07-30'){
                    $btnAvaliacao = 0;
                }else{
                    $btnAvaliacao = 1;
                }

                $lnModulos = [
                    'disciplina' => $ls->nomeDisciplina,
                    'docente' => $docente->name,                    
                    'dataInicio' => date('d/m/y', strtotime($dataInicio)),
                    'dataFim' => date('d/m/y', strtotime($dataFim)),
                    'sala' => $aulaProfessor->nomeSala,
                    'avaliacao' => $pesquisa->nivelSatisfacao,
                    'idPesquisa' => $pesquisa->id,
                    'btn' => $btnAvaliacao
                ];
                
                array_push($listaModulos, $lnModulos);
            }
        }

        // configuração de inadimplencia        
        $mensagemInadimplente = null;        
        if($request->session()->get('matricula')['inadimplente'] == 1){            
            $mensagemInadimplente = 'Prezado aluno, <a href="'.route('boleto.negociacao').'" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }

        if($request->session()->get('matricula')['modalidade'] == 2){
            return view('feedback.index2', compact('listaModulos', 'mensagemInadimplente'));
        }
        //return view('faq.index');
    }


    /**
     * Carrega formulário de Feedback para resposta do Aluno
     *
     * @param Request $request
     * @return void
     */
    public function formFeedback(Request $request)
    {
        $idPesquisa = $request->feed;
        $pesquisa = $this->pesqAluno->getPesquisaAluno($idPesquisa);        
        $empresa = $this->empresa->find($pesquisa->empresas_id);
        $perguntas = $this->pesqResposta->getRespostasPesquisaAluno($idPesquisa);
                
        /**
         * Verifica se há respostas já relacionadas a pesquisa que esta sendo chamada
         * Caso não haja, cadastra registro.
         */
        if($perguntas->count() == 0){
            $perguntaPesquisa = $this->pesqPergunta->getPerguntaPesquisa($pesquisa->tipoCurso, $empresa->id);
        
            foreach($perguntaPesquisa as $prgPsq){
                $this->pesqResposta->create([
                    'pesquisas_alunos_id' => $idPesquisa,
                    'pesquisas_perguntas_id' => $prgPsq->id,
                    'perguntaPesquisa' => $prgPsq->perguntaPesquisa
                ]);
            }
        
            $perguntas = $this->pesqResposta->getRespostasPesquisaAluno($idPesquisa);
        }

        // configuração de inadimplencia        
        $mensagemInadimplente = null;        
        if($request->session()->get('matricula')['inadimplente'] == 1){            
            $mensagemInadimplente = 'Prezado aluno, <a href="'.route('boleto.negociacao').'" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }


        return view('feedback.form', compact('pesquisa', 'empresa', 'perguntas', 'idPesquisa', 'mensagemInadimplente'));
    }

    /**
     * Atualiza Feedback do Aluno
     *
     * @param Request $request
     * @return void
     */
    public function upFeedback(Request $request)
    {
        // verifica se pesquisa existe
        $pesquisa = $this->pesqAluno->find($request->pesquisa);
        if(!$pesquisa){
            return redirect()
                    ->back()
                    ->with('error', 'Pesquisa não encontrada, por favor atualize sua página e tente novamente!');
        }

        // verifica se alguma resposta foi passada
        if(count($request->resposta) == 0){
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Parece que você não selecionou nenhuma resposta, por favor tente novamente.');
        }
        $i = 0;
        $totalResposta = 0;
        // atualiza respostas
        foreach($request->resposta as $resposta){
            $resp = explode("_", $resposta);

            $this->pesqResposta->where('id', $resp[0])->update(['respostaAluno' => $resp[1]]);
            // totaliza o total de pontos avaliados
            $totalResposta += $resp[1];
            $i++;
        }

        /**
         * Total de pontuação possível do professor no módulo
         * $i = total de respostas avaliadas
         * 5 = Total de possibilidades, 1=péssimo; 2-ruim, .... 5-excelente
         */
        $totalPontuacao = $i * 5;

        /**
         * Média de Satisfação
         * Calculada com base no totalPontuacao pelo totalResposa
         */
        $mediaSatisfacao = ($totalResposta * 100) / $totalPontuacao;

        /**
         * Atualiza média satisfação e status de feedback para respondido
         */
        $response = $pesquisa->update(['nivelSatisfacao' => $mediaSatisfacao, 'obsFeedback' => $request->obsFeed]);

        if($response){
            return redirect()
                    ->route('feedback.home')
                    ->with('success', 'Seu Feedback foi registrado com sucesso! Agradecemos sua colaboração para melhorarmos cada vez mais!');
        }else{
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Parece que houve uma falha de conexão com nosso servidor, por favor atualize sua página e tente novamente!');
        }
    }
}
