<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\Alunos_matricula;
use App\Models\Alunos_fatura;
use App\Models\Turma;
use App\Models\ComunicadosMensagens;
use App\Models\ComunicadosEnviados;
use App\Models\AlunosMatriculasDisciplinas;
use App\Models\LivePergunta;
use App\Models\AlunosAtendimento;
use App\Models\AlunosAtendimentoTipo;
use App\Models\Aluno;
use App\Models\Curso;
use App\Models\AlunosLog;
use App\Models\AlunosRematricula;

use Illuminate\Support\Facades\Auth;

class MoodleController extends Controller
{
    private $matricula, $fatura, $turma, $mensagem, $enviados, $disciplinas, $perguntas, $atendimento, $tipoAtendimento,
        $curso, $rematricula;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(
        Alunos_matricula $mat,
        Alunos_fatura $fat,
        Turma $trm,
        Request $request,
        ComunicadosEnviados $env,
        ComunicadosMensagens $msg,
        AlunosMatriculasDisciplinas $disc,
        LivePergunta $prg,
        AlunosAtendimento $atn,
        AlunosAtendimentoTipo $tpoAtn,
        Curso $crs,
        AlunosRematricula $rmt
    ) {
        $this->matricula = $mat;
        $this->fatura = $fat;
        $this->turma = $trm;
        $this->mensagem = $msg;
        $this->enviados = $env;
        $this->disciplinas = $disc;
        $this->perguntas = $prg;
        $this->atendimento = $atn;
        $this->tipoAtendimento = $tpoAtn;
        $this->curso = $crs;
        $this->rematricula = $rmt;
    }

    /**
     * Tela inicial, verifica se sessão de matrícula esta ativa
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {

        // verifica se sessão matricula já foi iniciada
        // dd($request);
        $url = $request->url();
        $newurl = explode("/", $url);

        if ($newurl[2] == 'carreira.saladeaulavirtual.com') {
            $template = 'layouts.appCarreira';
            $empresa = [6];
        } elseif ($newurl[2] == 'inex.saladeaulavirtual.com') {
            $template = 'layouts.appInex';
            $empresa = [9, 10, 12, 14, 15, 16, 17, 18];
        } else {
            $template = 'layouts.app';
            $empresa = [5, 7, 8];
        }

        // $newurl[1];
        if ($request->session()->get('matricula') == null) {
            $matriculas = $this->matricula->getMatriculaAluno(auth()->user()->cpfAluno);

            if ($matriculas->count() <= 0) {
                Auth::logout();
                $request->session()->flush();
                return redirect()->route('login')->with('error', 'Dados não encontrado');
            }

            /**
             * Caso o aluno possua apenas uma única matrícula já abre a sessão
             */
            if ($matriculas->count() == 1) {

                if (in_array($matriculas[0]->empresas_id, $empresa)) {
                    $turma = $this->turma->find($matriculas[0]->turmas_id);
                    $curso = $this->curso->find($turma->cursos_id);

                    // verifica qual id da empresa para atribuir dados pagseguro
                    if (in_array($matriculas[0]->empresas_id, [6, 13])) {
                        $emailPagseguro = env('PAGSEGURO_IC_EMAIL');
                        $tokenPagseguro = env('PAGSEGURO_IC_TOKEN');
                    } else if (in_array($matriculas[0]->empresas_id, [9, 10, 12, 14, 15, 16, 17, 18])) {
                        $emailPagseguro = env('PAGSEGURO_INX_EMAIL');
                        $tokenPagseguro = env('PAGSEGURO_INX_TOKEN');
                    } else {
                        $emailPagseguro = env('PAGSEGURO_EMAIL');
                        $tokenPagseguro = env('PAGSEGURO_TOKEN');
                    }

                    // cria sessão com as informações da matrícula selecionada
                    $request->session()->put('matricula', [
                        'idMatricula'       => $matriculas[0]->id,
                        'nomeAluno'         => $matriculas[0]->nomeAluno,
                        'codMatricula'      => $matriculas[0]->codMatricula,
                        'idCurso'           => $curso->id,
                        'siglaCurso'        => $curso->siglaCurso,
                        'nomeCurso'         => $curso->nomeCurso,
                        'nomeTurma'         => $turma->nomeTurma,
                        'modalidade'        => $matriculas[0]->modalidade,
                        'inadimplente'      => $matriculas[0]->inadimplente,
                        'linkava'           => $matriculas[0]->linkAva(),
                        'tipoCurso'         => $curso->tipoCurso,
                        'bolsa'             => $matriculas[0]->bolsas_id,
                        'bloqueioSAV'       => false,
                        'idEmpresa'         => $matriculas[0]->empresas_id,
                        'pagseguro_email'   => $emailPagseguro,
                        'pagseguro_token'   => $tokenPagseguro,
                        'nickempresa'       => Alunos_matricula::find($matriculas[0]->id)->nickEmpresa()
                    ]);

                    /**
                     * Registra Log de acesso
                     */
                    AlunosLog::create([
                        'sistema_id'            => 3,
                        'alunos_matriculas_id'  => $matriculas[0]->id,
                        'modulo'                => 7,
                        'acao'                  => 1,
                        'descAcao'              => 'Acessou a matrícula ' . $matriculas[0]->codMatricula . ', do curso ' . $curso->siglaCurso . ' ' . $curso->nomeCurso,
                        'ipAcesso'              => $request->ip(),
                        'agente'                => $request->header('user-agent')
                    ]);
                } else {
                    $response['message'] = 'Prezado aluno sua matricula não é dessa instituição.';
                    Auth::logout();
                    return redirect()->route('login')->with('error', $response['message']);
                }
            }

            return view('home.slcMatriculas', compact('matriculas', 'empresa'));
        }

        $matricula = $request->session()->get('matricula');
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        /**
         * Verifica se o aluno possui período de rematricula pendente
         */
        $checkRematricula =  $this->rematricula->getCheckRematricula($idMatricula);

        // caso não tenha sido ainda registrado os períodos de rematriculas o sistema registra
        if ($checkRematricula->count() == 0) {
            $this->getRegistroRematriculas($idMatricula);
        }

        $rematricula = $this->rematricula->getRematriculaPendente($idMatricula);
        if ($rematricula->count() > 0) {
            // verifica se o aluno esta inadimplente
            if ($request->session()->get('matricula')['inadimplente'] == 1) {
                // altera variavel de bloqueio do sav
                $dadosSessao = $request->session()->get('matricula');
                $dadosSessao['bloqueioSAV'] = true;
                $request->session()->put('matricula', $dadosSessao);

                return redirect()
                    ->route('boleto.negociacao')
                    ->with('error', 'Não foi possível realizar a renovação Automática da sua Matrícula devido as faturas a baixo estarem atrasadas em nosso sistema!');
            }

            // caso não esteja inadimplente renova período
            foreach ($rematricula as $rem) {
                $upRematricula = $this->rematricula->find($rem->id);

                $upRematricula->update([
                    'dataEfetivacao' => date('Y-m-d H:i:s'),
                    'obsRematricula' => 'Rematrícula Automática.',
                    'statusRematricula' => '1'
                ]);
            }
        }


        $mensagens = $this->mensagem->getMensagensAluno($idMatricula);
        $atendimento = $this->atendimento->getAtendimentoAlunoMatricula($idMatricula);
        //$disciplinas = $this->disciplinas->getDisciplinasMatriculaModulos($idMatricula);
        //dd($disciplinas);
        // verifica as matrículas x disciplinas relacionadas
        $disciplinaCurso = $this->matricula->getModulosMatriculaID($idMatricula);

        if (count($disciplinaCurso) > 0) {
            foreach ($disciplinaCurso as $dc) {
                // consulta se disciplina ja esta relacionada a matricula
                $matriculaDisciplina = $this->disciplinas->where('alunos_matriculas_id', $idMatricula)
                    ->where('disciplinas_id', $dc->idDisc)
                    ->get();

                if (count($matriculaDisciplina) == 0) {
                    $this->disciplinas->create([
                        'alunos_matriculas_id' => $idMatricula,
                        'disciplinas_id' => $dc->idDisc
                    ]);
                }
            }
        }

        /**
         * Registra Log de acesso
         */
        AlunosLog::create([
            'sistema_id'            => 3,
            'alunos_matriculas_id'  => $request->session()->get('matricula')['idMatricula'],
            'modulo'                => 7,
            'acao'                  => 1,
            'descAcao'              => 'Acessou a página inicial da área do aluno.',
            'ipAcesso'              => $request->ip(),
            'agente'                => $request->header('user-agent')
        ]);

        // configuração de inadimplencia
        $mensagemInadimplente = null;
        if ($request->session()->get('matricula')['inadimplente'] == 1) {
            $mensagemInadimplente = 'Prezado aluno, <a href="' . route('boleto.negociacao') . '" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }
        //dd($matricula);
        return view('home.indexHome', compact('matricula', 'mensagens', 'mensagemInadimplente', 'atendimento', 'template'));
    }

    /**
     * Adiciona a Matrícula a Varíavel de sessão
     *
     * @return \Illuminate\Http\Response
     */
    public function slcMatricula(Request $request, int $id)
    {
        // resgata dados da matrícula, curso, turma, etc...
        $matricula = $this->matricula->find($id);
        $aluno = Aluno::find($matricula->alunos_id);
        $turma = $this->turma->find($matricula->turmas_id);
        $curso = $this->curso->find($turma->cursos_id);

        // verifica qual id da empresa para atribuir dados pagseguro
        if (in_array($matricula->empresas_id, [6, 13])) {
            $emailPagseguro = env('PAGSEGURO_IC_EMAIL');
            $tokenPagseguro = env('PAGSEGURO_IC_TOKEN');
        } else if (in_array($matricula->empresas_id, [9, 10, 12, 14, 15, 16, 17, 18])) {
            $emailPagseguro = env('PAGSEGURO_INX_EMAIL');
            $tokenPagseguro = env('PAGSEGURO_INX_TOKEN');
        } else {
            $emailPagseguro = env('PAGSEGURO_EMAIL');
            $tokenPagseguro = env('PAGSEGURO_TOKEN');
        }

        // cria sessão com as informações da matrícula selecionada
        $request->session()->put('matricula', [
            'idMatricula'           => $id,
            'codMatricula'          => $matricula->codMatricula,
            'nomeAluno'             => $aluno->nomeAluno,
            'idCurso'               => $curso->id,
            'siglaCurso'            => $curso->siglaCurso,
            'nomeCurso'             => $curso->nomeCurso,
            'idTurma'               => $turma->id,
            'nomeTurma'             => $turma->nomeTurma,
            'modalidade'            => $matricula->modalidade,
            'inadimplente'          => $matricula->inadimplente,
            'linkava'               => $matricula->linkAva(),
            'tipoCurso'             => $curso->tipoCurso,
            'bolsa'                 => $matricula->bolsas_id,
            'bloqueioSAV'           => false,
            'idEmpresa'             => $matricula->empresas_id,
            'pagseguro_email'       => $emailPagseguro,
            'pagseguro_token'       => $tokenPagseguro,
            'nickempresa'           => Alunos_matricula::find($id)->nickEmpresa()

        ]);

        /**
         * Registra Log de acesso
         */
        AlunosLog::create([
            'sistema_id'            => 3,
            'alunos_matriculas_id'  => $matricula->id,
            'modulo'                => 7,
            'acao'                  => 1,
            'descAcao'              => 'Acessou a matrícula ' . $matricula->codMatricula . ', do curso ' . $curso->siglaCurso . ' ' . $curso->nomeCurso,
            'ipAcesso'              => $request->ip(),
            'agente'                => $request->header('user-agent')
        ]);

        $aln = Aluno::find(auth()->user()->id);
        $aluno = $aln->getConsultaCPF(auth()->user()->cpfAluno);
        if (count($aluno) > 0) {

            // cria sessão com as informações da matrícula selecionada
            $request->session()->put('aluno', [
                'idAluno' => $aluno[0]->id,
                'nomeAluno' => $aluno[0]->nomeAluno,
                'cpfAluno' => $aluno[0]->cpfAluno
            ]);
        }
        return redirect()
            ->route('home.moodle')
            ->with('success', 'Matrícula selecionada com sucesso!');
    }

    /**
     * Deleta a session Matrícula a Varíavel de sessão
     *
     * @return \Illuminate\Http\Response
     */
    public function dslcMatricula(Request $request)
    {
        // deleta sessão com as informações da matrícula selecionada
        $request->session()->forget('matricula');

        return redirect()
            ->route('home.moodle');
    }

    /**
     * registra períodos de rematriculas
     *
     * @param integer $idMatricula
     * @return void
     */
    private function getRegistroRematriculas(int $idMatricula)
    {
        $matricula = $this->matricula->find($idMatricula);

        for ($x = 1; $x <= 6; $x++) {
            $dias = 90 * $x;
            $dataRematricula = date('Y-m-d', strtotime("+{$dias} days", strtotime($matricula->created_at)));

            $lnRematricula = [
                'alunos_matriculas_id' => $matricula->id,
                'ordemRematricula' => $x,
                'dataRematricula' => $dataRematricula,
                'statusRematricula' => 0
            ];

            $this->rematricula->create($lnRematricula);
        }

        return true;
    }
}
