<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\SuporteAssunto;
use App\Models\SuporteAnexo;
use App\Models\SuporteSolicitacao;
use App\Models\SuporteMensagens;
use App\Models\SuporteMensagensAnexos;
use App\Models\Alunos_fatura;

class SuporteController extends Controller
{
    private $assunto, $anexo, $solicitacao, $mensagem, $msgAnexo, $faturas;
    
    public function __construct(SuporteAssunto $ass, 
                                SuporteAnexo $anx, 
                                SuporteSolicitacao $sol, 
                                SuporteMensagens $msg,
                                SuporteMensagensAnexos $msgAnx,
                                Alunos_fatura $fat) {
        $this->assunto = $ass;
        $this->anexo = $anx;
        $this->solicitacao = $sol;
        $this->mensagem = $msg;
        $this->msgAnexo = $msgAnx;
        $this->faturas = $fat;
    }
    
    /**
     * Tela inicial de Suporte via Acesso Moodle
     * @param Request $request
     * @return type
     */
    public function index(Request $request)
    {
        // verifica se sessão matricula já foi iniciada
        if(!isset($request->session()->get('matricula')['idMatricula'])){
            return redirect()
                    ->route('home.moodle')
                    ->with('warning', 'Atenção! Você precisa selecionar uma matrícula abaixo!');
        }
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        
        $assunto = $this->assunto->orderBy('tituloAssunto')->where('statusAssunto', 1)->get();
        $solicitacoes = $this->solicitacao->getSolicitacaoAluno($idMatricula);

        // configuração de inadimplencia        
        $mensagemInadimplente = null;        
        if($request->session()->get('matricula')['inadimplente'] == 1){            
            $mensagemInadimplente = 'Prezado aluno, <a href="'.route('boleto.negociacao').'" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }
        
        return view('suporte.index', compact('assunto', 'solicitacoes', 'mensagemInadimplente'));
    }
    
    /**
     * Registra solicitação de suporte
     *
     * @param Request $request
     * @return void
     */
    public function store(Request $request)
    {
        $idMatricula = $request->session()->get('matricula')['idMatricula'];
        // gera código da solicitação
        $codigo = $this->getCodigo();
        // gera prazo da solicitação - 48 horas úteis
        $prazo = $this->validaVcto(date('Y-m-d', strtotime('+48 hours')));

        $dados = [
            'alunos_matriculas_id' => $idMatricula,
            'suporte_assuntos_id' => $request->assunto,
            'codigoSolicitacao' => $codigo,
            'descSolicitacao' => $request->msg,
            'prazoResposta' => $prazo,
            'emAtraso' => 0,
            'statusSolicitacao' => 0
        ];
        
        $response = $this->solicitacao->create($dados);
        
        if($response){
            // verifica se passou algum arquivo
            if($request->hasFile('arquivo') && $request->file('arquivo')->isValid()){
                $nomeArquivo = $codigo."-".kebab_case($request->file('arquivo')->getClientOriginalName()); // define nome
                $extensao = $request->file('arquivo')->extension(); // pega a extensão do arquivo
                $novoNome = "{$nomeArquivo}.{$extensao}";
                $upload = $request->file('arquivo')->storeAs('arquivos/suporte', $novoNome);

                // registra no banco
                $ddFile = [
                    'suporte_solicitacao_id' => $response->id,
                    'nomeArquivo' => $novoNome
                ];                

                $this->anexo->create($ddFile);
            }

            return redirect()
                    ->route('suporte.home', ['suc'=>'true'])
                    ->with('success', 'Solicitação registrada com sucesso!');
        }else{
            return redirect()
                    ->back()
                    ->with('error', 'Ops! Erro ao registrar sua solicitação, por favor atualize sua página e tente novamente!');
        }

    }
    
    /**
     * Exibe detalhes do suporte para acompanhamento
     *
     * @param integer $id
     * @return void
     */
    public function show(int $id, Request $request)
    {
        $chamado = $this->solicitacao->find($id);
        $assunto = $this->assunto->find($chamado->suporte_assuntos_id);
        $anexos = $this->anexo->where('suporte_solicitacao_id', $id)->get();
        $mensagem = $this->mensagem->getMensagensChamado($id);  
        
        if(count($mensagem) > 0){
            $msgAnexo = $this->msgAnexo->where('suporte_mensagens_id', $mensagem[0]->id)->first();
        }else{
            $msgAnexo = '';
        }
        $dataResposta = $this->mensagem->where('suporte_solicitacao_id', $id)->latest()->first();

        // configuração de inadimplencia        
        $mensagemInadimplente = null;        
        if($request->session()->get('matricula')['inadimplente'] == 1){            
            $mensagemInadimplente = 'Prezado aluno, <a href="'.route('boleto.negociacao').'" class="white-text" title="Negociar Débitos" style="text-decoration: underline"><b>clique aqui</b></a> para negociar seus débitos com a Instituição.';
        }

        return view('suporte.show', compact('chamado', 'assunto', 'anexos', 'mensagem', 'msgAnexo', 'dataResposta', 'mensagemInadimplente'));
    }


    /**
     * Gera Código da Solicitação
     * Ex: 2018122100012
     * Onde:
     * - 2018 => ano atual;
     * - 12 => mês atual;
     * - 21 => dia da solicitação;
     * - 00012 => ID corrente do registro na base de dados.
     *
     * @return void
     */
    private function getCodigo()
    {
        $ultimoReg = $this->solicitacao->all()->last();
        if($ultimoReg){
            $id = $ultimoReg->id + 1;
        }else{
            $id = 1;
        }
        $ano = date('Y');
        $mes = date('m');
        $dia = date('d');
        return $ano.$mes.$dia.str_pad($id, 5, 0, STR_PAD_LEFT);
    }

    /**
     * Função que valida as datas de vencimentos de pazos, para que elas não caiam em finais de semana
     * $dtVcto = yyyy-mm-dd
     *
     * @param [type] $dtVcto
     * @return void
     */
    public function validaVcto($dtVcto)
    {
        // desmembra data
        $data = explode('-', $dtVcto);
        // transforma a data para tempo para calculos e conversões
        $dtTime = mktime(0, 0, 0, $data[1], $data[2], $data[0]);
        
        // verifica qual o dia da semana a data caiu
        // caso seja domingo adiciona 1 dia para cair na segunda
        // caso seja sábado subtrai 1 dia para cair na sexta
        $diaSem = date('w', $dtTime);
        switch($diaSem){
            // domingo
            case 0 : 
                $difData = intval($data[2])+1;
            break;
            // sábado
            case 6 : 
                $difData = intval($data[2])+2;
            break;
            // mantém mesma data
            default :
                $difData = $data[2];
            break;
        }
        // calcula nova data
        $nwTime = mktime(0,0,0, $data[1], $difData, $data[0]);
        $novaData = date('Y-m-d', $nwTime);
        
        return $novaData;
    }
    
}
