<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class AlunosMatriculasFrequencias extends Model
{
    protected $fillable = ['disciplinas_aulas_id', 'matriculas_disciplinas', 'presencaAcademico', 'horaAula'];

    /**
     * Consulta se o aluno esta presente na lista de frequencia
     *
     * @param integer $aula
     * @param integer $matricula
     * @param integer $disciplina
     * @return void
     */
    public function getFrequenciaAula(int $aula, int $matricula, int $disciplina)
    {
        return $this->join('alunos_matriculas_disciplinas', 'alunos_matriculas_disciplinas.id', 'alunos_matriculas_frequencias.matriculas_disciplinas')
                    ->where('alunos_matriculas_frequencias.disciplinas_aulas_id', $aula)
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $matricula) 
                    ->where('alunos_matriculas_disciplinas.disciplinas_id', $disciplina)
                    ->select('alunos_matriculas_frequencias.*')
                    ->first();
    }
    
    /**
     * Consulta a frequência do aluno em uma determinada Disciplina
     *
     * @param integer $matricula
     * @param integer $disciplina
     * @return void
     */
    public function getFrequenciaDisciplina(int $matricula, int $disciplina)
    {
        return $this->join('alunos_matriculas_disciplinas', 'alunos_matriculas_disciplinas.id', 'alunos_matriculas_frequencias.matriculas_disciplinas')
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $matricula) 
                    ->where('alunos_matriculas_disciplinas.disciplinas_id', $disciplina)
                    ->select('alunos_matriculas_frequencias.*')
                    ->get();
    }
    
    /**
     * Consulta a frequência do aluno em uma determinada Disciplina de acordo com sua presença
     *
     * @param integer $matricula
     * @param integer $disciplina
     * @param integer $sts
     * @return void
     */
    public function getFrequenciaDisciplinaSts(int $matricula, int $disciplina, int $sts)
    {
        return $this->join('alunos_matriculas_disciplinas', 'alunos_matriculas_disciplinas.id', 'alunos_matriculas_frequencias.matriculas_disciplinas')
                    ->where('alunos_matriculas_disciplinas.alunos_matriculas_id', $matricula) 
                    ->where('alunos_matriculas_disciplinas.disciplinas_id', $disciplina)
                    ->where('alunos_matriculas_frequencias.presencaAcademico', $sts)
                    ->select('alunos_matriculas_frequencias.*')
                    ->get();
    }
}
