<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use DB;

class Alunos_fatura extends Model{

    protected $fillable = [
        'alunos_matriculas_id', 'codFatura', 'dataVcto', 'valorFatura',
        'valorDesconto', 'valorDesconto2', 'qtdeParcela', 'parcelaCorrente',
        'tipoPagto', 'statusFatura', 'observacoes', 'emAtraso', 'registradaBco'
    ];

    // lista faturas por aluno
    public function getFaturasAluno(int $aluno){
        $lista = $this->join('alunos_matriculas','alunos_matriculas.id', '=', 'alunos_faturas.alunos_matriculas_id')
                        ->join('boletos_gerados', 'alunos_faturas.id', '=', 'boletos_gerados.alunos_faturas_id')
                        ->where('alunos_matriculas.alunos_id', $aluno)
                        ->where('alunos_faturas.registradaBco', 1)
                        //->where('alunos_faturas.statusFatura', '<=', 3)
                        ->select('alunos_faturas.id as idFatura', 'alunos_faturas.*', 'boletos_gerados.valorRecebido', 'boletos_gerados.dataCredito', 'boletos_gerados.alunos_faturas_id')
                        ->orderBy('alunos_faturas.dataVcto', 'asc')
                        ->groupBy('boletos_gerados.alunos_faturas_id')
                        ->get();

        return $lista;
    }

    // lista faturas por matrículas
    public function getFaturasMatricula(int $matricula){
        $lista = $this->where('alunos_matriculas_id', $matricula)
                    ->where('tipoFatura', '1')
                    ->orderBy('dataVcto', 'asc')
                    ->get();

        return $lista;
    }

    /**
     * Lista faturas no contrato do aluno
     *
     * @param integer $aluno
     * @return void
     */
    public function getFaturasContratoAluno(int $aluno){
        $lista = $this->join('alunos_matriculas','alunos_matriculas.id', '=', 'alunos_faturas.alunos_matriculas_id')
                        ->where('alunos_matriculas.id', $aluno)
                        ->where('alunos_faturas.tipoFatura', 1)
                        ->where('alunos_faturas.statusFatura', '<', 5)
                        ->select('alunos_faturas.id as idFatura', 'alunos_faturas.*')
                        ->orderBy('alunos_faturas.dataVcto', 'asc')
                        ->get();

        return $lista;
    }

    // lista faturas por aluno e matricula
    public function getFaturasAlunoMatricula(int $aluno, int $matricula, $dataVcto){
        $lista = $this->join('alunos_matriculas','alunos_matriculas.id', 'alunos_faturas.alunos_matriculas_id')
                        //->join('boletos_gerados', 'alunos_faturas.id', 'boletos_gerados.alunos_faturas_id')
                        //->where('alunos_matriculas.alunos_id', $aluno)
                        ->where('alunos_matriculas.id', $matricula)
                        ->whereIn('alunos_faturas.registradaBco', [0,1])
                        ->whereIn('alunos_faturas.statusFatura', [0,1,2,3,6,7])
                        //->whereIn('alunos_faturas.registradaBco', [1])
                        ->where('alunos_faturas.tipoFatura', 1)
                        //->where('alunos_faturas.dataVcto', '<=', $dataVcto)
                        ->select('alunos_faturas.id as idFatura', 'alunos_faturas.*')
                        ->orderBy('alunos_faturas.dataVcto', 'asc')
                        //->groupBy('boletos_gerados.alunos_faturas_id')
                        ->get();

        return $lista;
    }

    /**
     * Lista faturas pagas apenas por idMatricula e ano base de pagamento
     * Método utilizado para calculo e consulta de documento de declaração de IR
     * @param int $matricula
     * @return type
     */
    public function getFaturasPagasMatricula(int $matricula, $anoBase){
        $lista = $this->join('alunos_matriculas','alunos_matriculas.id', 'alunos_faturas.alunos_matriculas_id')
                    ->join('boletos_gerados', 'boletos_gerados.alunos_faturas_id', 'alunos_faturas.id')
                    ->where('alunos_matriculas.id', $matricula)
                    ->where('alunos_faturas.statusFatura', 2)
                    ->whereBetween('boletos_gerados.dataCredito', [date($anoBase.'-01-01 00:00:00'), date($anoBase.'-12-31 23:59:59')])
                    ->select('alunos_faturas.id as idFatura', 'alunos_faturas.*', 'boletos_gerados.*')
                    ->orderBy('alunos_faturas.dataVcto', 'asc')
                    ->get();

        return $lista;
    }

    /**
     * Lista faturas atrasadas apenas por idMatricula
     * Método utilizado para modulo de negociação
     * @param int $matricula
     * @return type
     */
    public function getFaturasAtrasadasMatricula(int $matricula){
        $lista = $this->join('alunos_matriculas','alunos_matriculas.id', 'alunos_faturas.alunos_matriculas_id')
                    ->where('alunos_faturas.statusFatura', 1)
                    ->where('alunos_matriculas.id', $matricula)
                    ->select('alunos_faturas.id as idFatura', 'alunos_faturas.*')
                    ->orderBy('alunos_faturas.dataVcto', 'asc')
                    ->select('alunos_faturas.*')
                    ->get();

        return $lista;
    }


}
