<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
//use Illuminate\Support\Facades\Crypt;
use Illuminate\Encryption\Encrypter;

class Alunos_matricula extends Model
{
    protected $fillable = [
        'codMatricula', 'empresas_id', 'alunos_id', 'turmas_id', 'bolsas_id', 'valorCurso', 'valorDesconto',
        'valorMatricula', 'qtdeParcela', 'statusMatricula', 'statusAluno', 'observacoes', 'motivoCancelamento'
    ];

    /**
     * Lista matriculas do aluno pelo cpf
     * @param string $cpfAluno
     * @return type
     */
    public function getMatriculaAluno(string $cpfAluno)
    {
        $query = $this->join('turmas', 'alunos_matriculas.turmas_id', 'turmas.id')
            ->join('alunos', 'alunos.id', 'alunos_matriculas.alunos_id')
            ->join('cursos', 'cursos.id', 'turmas.cursos_id')
            ->join('empresas', 'empresas.id', 'alunos_matriculas.empresas_id')
            ->where('alunos.cpfAluno', $cpfAluno)
            ->where(function ($query) {
                $query->where('turmas.plataformaAcesso', 1)
                    ->orWhereNull('turmas.plataformaAcesso');
            })
            ->whereNotIn('alunos_matriculas.statusMatricula', ['2', '6'])
            ->orderBy('alunos_matriculas.codMatricula')
            ->select('cursos.siglaCurso', 'cursos.nomeCurso', 'cursos.cursoPromo', 'turmas.*', 'empresas.logoEmpresa', 'empresas.nomeFantasia', 'alunos_matriculas.id as idMatricula', 'alunos_matriculas.*')
            ->get();
        return $query;
    }

    /**
     * Lista Matriculas do Aluno pelo ID dele
     * @param int $idAluno
     * @return type
     */
    public function getMatriculaIDAluno(int $idAluno)
    {
        return $this->join('turmas', 'alunos_matriculas.turmas_id', 'turmas.id')
            ->join('alunos', 'alunos.id', 'alunos_matriculas.alunos_id')
            ->join('cursos', 'cursos.id', 'turmas.cursos_id')
            ->join('empresas', 'empresas.id', 'alunos_matriculas.empresas_id')
            //->join('cursos', 'turmas.cursos_id', 'cursos.id')
            ->where('alunos_matriculas.id', $idAluno)
            ->orderBy('alunos_matriculas.codMatricula')
            ->select(
                'cursos.siglaCurso',
                'cursos.nomeCurso',
                'turmas.nomeTurma',
                'empresas.*',
                'alunos_matriculas.id as idMatricula',
                'alunos_matriculas.codMatricula',
                'alunos.nomeAluno',
                'alunos.cpfAluno'
            )
            ->get();
    }

    /**
     * Lista Dados do aluno matriculado, pelo ID da Matrícula
     *
     * @param integer $idMatricula
     * @return void
     */
    public function getAlunoDadosMatriculaID(int $idMatricula)
    {
        return $this->join('alunos', 'alunos.id', 'alunos_matriculas.alunos_id')
            ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
            ->join('cursos', 'cursos.id', 'turmas.cursos_id')
            ->join('empresas', 'empresas.id', 'alunos_matriculas.empresas_id')
            ->where('alunos_matriculas.id', $idMatricula)
            ->select('alunos.nomeAluno', 'alunos.cpfAluno', 'alunos.nacionalidade', 'alunos.cpfAluno', 'alunos.foneFixo', 'alunos.foneCelular', 'alunos.cidadeAluno', 'alunos.ufAluno', 'alunos_matriculas.codMatricula', 'cursos.siglaCurso', 'cursos.nomeCurso', 'turmas.nomeTurma', 'alunos_matriculas.empresas_id', 'alunos_matriculas.created_at', 'empresas.razaoSocial', 'empresas.nomeFantasia')
            ->first();
    }

    /**
     * Lista Disciplinas (Módulos) relacinados ao curso e turma matrículados.
     *
     * @param integer $idMatricula
     * @return 
     */
    public function getModulosMatriculaID(int $idMatricula)
    {
        return $this->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
            ->join('cursos', 'cursos.id', 'turmas.cursos_id')
            ->join('cursos_disciplinas', 'cursos_disciplinas.curso_id', 'cursos.id')
            ->join('disciplinas', 'disciplinas.id', 'cursos_disciplinas.disciplina_id')
            ->where('alunos_matriculas.id', $idMatricula)
            ->orderBy('disciplinas.nomeDisciplina', 'asc')
            ->select('disciplinas.id as idDisc', 'disciplinas.*')
            ->get();
    }

    /**
     * Lista dados de uma determinada matrícula e aluno
     *
     * @param integer $idMatricula
     * @return object
     */
    public function getDadosMatricula(int $idMatricula)
    {
        return $this->join('alunos', 'alunos.id', 'alunos_matriculas.alunos_id')
            ->join('turmas', 'turmas.id', 'alunos_matriculas.turmas_id')
            ->join('cursos', 'cursos.id', 'turmas.cursos_id')
            ->where('alunos_matriculas.id', $idMatricula)
            ->select(
                'alunos.nomeAluno',
                'alunos.cpfAluno',
                'alunos.emailAluno',
                'alunos_matriculas.id as idMatricula',
                'alunos.foneFixo',
                'alunos.foneCelular',
                'alunos.cidadeAluno',
                'alunos.ufAluno',
                'alunos_matriculas.id as idMatricula',
                'alunos_matriculas.empresas_id as empresa',
                'alunos_matriculas.codMatricula',
                'alunos_matriculas.statusMatricula',
                'alunos_matriculas.statusMatricula',
                'alunos_matriculas.modalidade',
                'alunos_matriculas.inadimplente',
                'alunos_matriculas.created_at as dataMatricula',
                'turmas.nomeTurma',
                'cursos.id as idCurso',
                'cursos.siglaCurso',
                'cursos.nomeCurso',
                'turmas.id as idTurma'
            )
            ->first();
    }

    public function linkAva()
    {
        $data = array('id' => $this->id);
        $params = json_encode($data);

        $chave = "(_e_s_t_r_a_t_e_g_o_@_2_0_1_9_).";
        $newEncrypter = new Encrypter($chave, config('app.cipher'));
        $link = env('LINKAVA', 'http://sav.universidade.site/aluno') . '/';
        // $link = 'http://127.0.0.1:8081/aluno/';

        return $link . $newEncrypter->encrypt($params);
    }


    public function faturas()
    {
        return $this->hasMany('App\Models\Alunos_fatura', 'alunos_matriculas_id');
    }

    public function faturasAtrasadas()
    {
        return $this->faturas()->where('emAtraso', 2);
    }

    //Modulo de negociação 
    //Retorna a lista de negociações
    public function negociacao()
    {
        return $this->hasMany('App\Models\AlunosNegociacao', 'alunos_matriculas_id', 'id');
    }

    //Retorna falso se teve alguma negociação não quitada
    //Retirna true se todas as negociaçõe sestiverem quitadas
    public function negociacoesTodasQuitadas()
    {
        $negociacoes = $this->negociacao()->get();
        foreach ($negociacoes as $nego) {
            if (!$nego->quitada()) {
                return false;
            }
        }
        return true;
    }

    //Retorna a quantidade de negociaçoes
    public function qtdNegocicaoNaoQuitadas()
    {
        $negociacoes = $this->negociacao()->get();
        $conta = 0;
        foreach ($negociacoes as $nego) {
            if (!$nego->quitada()) {
                $conta++;
            }
        }
        return $conta;
    }
    //Retorna true se a matricula estive habilita a fazer negociação, false caso contrario
    public function isHabilitadoNegociar()
    {
        if ($this->qtdNegocicaoNaoQuitadas() >= 1) {
            return false;
        } else {
            return true;
        }
        //return true;
    }

    public function qtdNegocicaoAntigasNaoQuitadas()
    {
        $negociacoes = $this->negociacao()->where('created_at', '<=', '2020-04-20')->orderBy('id', 'DESC')->get();
        $conta = 0;
        foreach ($negociacoes as $nego) {
            if ($conta < 1) {
                if (!$nego->encerrada()) {
                    $conta++;
                }
            } else {
                if (!$nego->quitada()) {
                    $conta++;
                }
            }
        }
        return $conta;
    }


    public function negociacaoCondicao()
    {
        //dd($this->faturasAtrasadas()->count());
        //Condição até dia 15 de maio
        if ($this->qtdNegocicaoAntigasNaoQuitadas() >= 2 || $this->faturasAtrasadas()->count() >= 2) {
            return 2;
        } else {
            return 1;
        }
        //Codição real
        //if($this->qtdNegocicaoAntigasNaoQuitadas() >= 2){ return 2;}else{return 1;}
        //return 2;
    }


    public function nickEmpresa()
    {

        switch ($this->empresas_id) {
            case 5:
            case 7:
            case 8:
            case 11:
                return "estratego";

            case 6:
            case 13:
                return "carreira";

            case 9:
            case 10:
            case 12:
            case 14:
            case 15:
            case 16:
            case 17:
            case 18:
                return "inex";
        }
    }

    public function aluno()
    {
        return $this->belongsTo(Aluno::class, 'alunos_id');
    }

    public function turma()
    {
        return $this->belongsTo(Turma::class, 'turmas_id');
    }

    public function empresa()
    {
        return $this->belongsTo(Empresa::class, 'empresas_id');
    }
}
