<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class DisciplinasUnidadesRecurso extends Model
{

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = ['disciplinas_unidades_id', 'ordemRecurso', 'tipoRecurso', 'nomeRecurso', 'pontosGame', 'statusRecurso'];

    protected $connection = 'mysql_sav';

    /**
     * Lista recursos de uma determinada unidade
     *
     * @param integer $idUnidade
     * @return object
     */
    public function getRecursoUnidade(int $idUnidade)
    {
        return $this->where('disciplinas_unidades_id', $idUnidade)
                    ->orderBy('ordemRecurso', 'asc')
                    ->get();
    }

    /**
     * Lista dados de Curso, Disciplina e Unidade, relacionado a um recurso
     *
     * @param integer $idRecurso
     * @return object
     */
    public function getRecursoUnidadeDiscCurso(int $idRecurso)
    {
        return $this->join('disciplinas_unidades', 'disciplinas_unidades.id', 'disciplinas_unidades_recursos.disciplinas_unidades_id')
        ->join('disciplinas_ead', 'disciplinas_ead.id', 'disciplinas_unidades.disciplinas_ead_id')
        ->where('disciplinas_unidades_recursos.id', $idRecurso)
        ->select('disciplinas_unidades_recursos.*', 'disciplinas_unidades.nomeUnidade', 'disciplinas_unidades.diasLiberacaoUnidade', 'disciplinas_unidades.statusUnidade',
                 'disciplinas_ead.id as idEAD', 'disciplinas_ead.curso_id', 'disciplinas_ead.turmas_id',
                 'disciplinas_ead.disciplina_id', 'disciplinas_ead.diasLiberacao', 'disciplinas_ead.statusDisciplina')
        ->first();
    }

    /**
     * Lista recursos de uma determinada unidade habilitada para aluno
     *
     * @param integer $idUnidade
     * @return object
     */
    public function getRecursoUnidadeAluno(int $idUnidade)
    {
        return $this->where('disciplinas_unidades_id', $idUnidade)
                    ->where('statusRecurso', '1')
                    ->orderBy('ordemRecurso', 'asc')
                    ->get();
    }
}
