<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

use DB;

class RecursosFeedback extends Model
{
    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'recursos_feedback';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = ['alunos_matriculas_id', 'disciplinas_ead_id', 'satisfacao_professor', 'comentario_professor', 'satisfacao_material', 'comentario_material'
    , 'satisfacao_disciplina', 'comentario_sav','satisfacao_sav','comentario_ebook','satisfacao_ebook'];

    protected $connection = 'mysql_sav';


    /**
     * Lista empresas por usuario
     *
     * @param int $idUser
     * @return mixed
     */
    public function getVerifica(int $iddisciplina, int $idAluno)
    {
        return $this->where('disciplinas_ead_id', $iddisciplina)
                    ->where('alunos_matriculas_id', $idAluno)
                    ->get();
    }

    public function getRelatorio(int $id){
        return $this->whereIn('alunos_matriculas_id',$id)
                    
                    ->get('satisfacao_sav', 'disciplinas_ead_id' , 'alunos_matriculas_id' );
    }

    public function getRelatorioAluno(int $id , int $iddisciplina){
        return $this->where('alunos_matriculas_id',$id)
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->get();
    }

    public function getRelatorioAlunoTurma(int $id ){
        return $this->where('alunos_matriculas_id',$id)
                    ->get();
    }

    public function getDisciplinaTotal(array $listamatricula , int $iddisciplina , $dataInicial,  $dataFinal){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->where('disciplinas_ead_id', $iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id')
                    ->get();
    }

    public function getTotalDisciplina(int $iddisciplina, $dataInicial,  $dataFinal){
        return $this
                    ->where('disciplinas_ead_id', $iddisciplina)                 
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id')
                    ->get();
    }

    public function getRelatorioConta(array $listamatricula , int $iddisciplina,  $dataInicial,  $dataFinal){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id', 'satisfacao_professor')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_professor')
                    ->get();
    }
    public function getRelatorioContaTurma(array $listamatricula ){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->groupby('disciplinas_ead_id', 'satisfacao_professor')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_professor')
                    ->get();
    }

    public function getRelatorioContaDisciplina(int $iddisciplina, $dataInicial,  $dataFinal){
        return $this->where('disciplinas_ead_id',$iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id', 'satisfacao_professor')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_professor')
                    ->get();
    }

    public function getSatisfacaoMaterial(array $listamatricula , int $iddisciplina , $dataInicial,  $dataFinal){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id', 'satisfacao_material')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_material')
                    ->get();
    }

    public function getSatisfacaoDisciplina(array $listamatricula , int $iddisciplina, $dataInicial,  $dataFinal){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id', 'satisfacao_disciplina')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_disciplina')
                    ->get();
    }

    public function getSatisfacaoSav(array $listamatricula , int $iddisciplina, $dataInicial,  $dataFinal){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id', 'satisfacao_sav')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_sav')
                    ->get();
    }

    public function getSatisfacaoMaterialTurma(array $listamatricula ){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->groupby('disciplinas_ead_id', 'satisfacao_material')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_material')
                    ->get();
    }

    public function getSatisfacaoDisciplinaTurma(array $listamatricula ){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->groupby('disciplinas_ead_id', 'satisfacao_disciplina')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_disciplina')
                    ->get();
    }

    public function getSatisfacaoSavTurma(array $listamatricula ){
        return $this->whereIn('alunos_matriculas_id',$listamatricula)
                    ->groupby('disciplinas_ead_id', 'satisfacao_sav')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_sav')
                    ->get();
    }

    
    public function getDisSatisfacaoMaterial( int $iddisciplina, $dataInicial,  $dataFinal){
        return $this
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id', 'satisfacao_material')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_material')
                    ->get();
    }

    public function getDisSatisfacaoDisciplina( int $iddisciplina,  $dataInicial,  $dataFinal){
        return $this
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id', 'satisfacao_disciplina')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_disciplina')
                    ->get();
    }

    public function getDisSatisfacaoSav( int $iddisciplina,$dataInicial,  $dataFinal){
        return $this
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->whereBetween('created_at', [$dataInicial,$dataFinal])
                    ->groupby('disciplinas_ead_id', 'satisfacao_sav')
                    ->select(DB::raw('count(id) as id') ,'disciplinas_ead_id', 'satisfacao_sav')
                    ->get();
    }

    public function getRelatorioDisciplina( int $iddisciplina){
        return $this
                    ->where('disciplinas_ead_id',$iddisciplina)
                    ->groupby('disciplinas_ead_id', 'satisfacao_sav')
                    ->get();
    }

    
}
